==> k4de-0.3.0.tgz: k4de-0.3.0/src/3d/objects/camera.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** camera.h
*/
#ifndef __CAMERA_H__
#define __CAMERA_H__

#include "view.h"

class camera : public body
{
protected:
	view	*viewptr;

public:
	camera(base *p = 0,const char *n="Untitled",view *v = 0);
	camera(base *p,camera*);
	~camera();

	void		setView(view*);
	view		*getView();
	
	virtual int	addToParent(base*);
	virtual int	removeFromParent();

	virtual base	*copy(base *parent);

	virtual int	exportPOV(FILE*,int tab,int tabsize,int anim = 0);

	virtual void	dumpNames(int tab,int tabsize);

	virtual int	save(media*);
	virtual int	load(media*,int);

	virtual int	calculate(int anim);
	virtual int	draw(view*,Matrix44,int);

	virtual double	volume(int);
};

#endif

==> k4de-0.4.0.tgz: k4de-0.4.0/src/3d/objects/camera.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** camera.h
*/
#ifndef __CAMERA_H__
#define __CAMERA_H__

#include "view.h"

class camera : public body
{
protected:
	view	*viewptr;

public:
	camera(base *p = 0,const char *n="Untitled",view *v = 0);
	camera(base *p,camera*);
	~camera();

	void		setView(view*);
	view		*getView();
	
	virtual int	addToParent(base*);
	virtual int	removeFromParent();

	virtual base	*copy(base *parent);

	virtual int	exportPOV(FILE*,int tab,int tabsize,int anim = 0);

	virtual void	dumpNames(int tab,int tabsize);

	virtual int	save(media*,int);
	virtual int	load(media*,int,int);

	virtual int	calculate(int anim);
	virtual int	draw(view*,Matrix44,int);

	virtual double	volume(int);
};

#endif
